# TableRowStyle

Styles that apply to a table row.

**Type:** object

## Properties

- **minRowHeight** ([Dimension](dimension.md)): The minimum height of the row. The row will be rendered in the Docs editor at a height equal to or greater than this value in order to show all the content in the row's cells.
- **tableHeader** (boolean): Whether the row is a table header.
- **preventOverflow** (boolean): Whether the row cannot overflow across page or column boundaries.
